@@ -2,7 +2,8 @@
 #
 # Tests for XlsxWriter.
 #
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# SPDX-License-Identifier: BSD-2-Clause
+# Copyright (c), 2013-2024, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -16,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('chart_format03.xlsx')
+        self.set_filename("chart_format03.xlsx")
 
     def test_create_file(self):
         """Test the creation of an XlsxWriter file with chart formatting."""
@@ -25,7 +25,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         workbook = Workbook(self.got_filename)
 
         worksheet = workbook.add_worksheet()
-        chart = workbook.add_chart({'type': 'column'})
+        chart = workbook.add_chart({"type": "column"})
 
         chart.axis_ids = [46175744, 46319488]
 
@@ -33,26 +33,29 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
             [1, 2, 3, 4, 5],
             [2, 4, 6, 8, 10],
             [3, 6, 9, 12, 15],
-
         ]
 
-        worksheet.write_column('A1', data[0])
-        worksheet.write_column('B1', data[1])
-        worksheet.write_column('C1', data[2])
+        worksheet.write_column("A1", data[0])
+        worksheet.write_column("B1", data[1])
+        worksheet.write_column("C1", data[2])
 
-        chart.add_series({
-            'categories': '=Sheet1!$A$1:$A$5',
-            'values': '=Sheet1!$B$1:$B$5',
-            'border': {'color': 'yellow'},
-            'fill': {'color': 'red'},
-        })
+        chart.add_series(
+            {
+                "categories": "=Sheet1!$A$1:$A$5",
+                "values": "=Sheet1!$B$1:$B$5",
+                "border": {"color": "yellow"},
+                "fill": {"color": "red"},
+            }
+        )
 
-        chart.add_series({
-            'categories': '=Sheet1!$A$1:$A$5',
-            'values': '=Sheet1!$C$1:$C$5',
-        })
+        chart.add_series(
+            {
+                "categories": "=Sheet1!$A$1:$A$5",
+                "values": "=Sheet1!$C$1:$C$5",
+            }
+        )
 
-        worksheet.insert_chart('E9', chart)
+        worksheet.insert_chart("E9", chart)
 
         workbook.close()
 
