@@ -2,7 +2,8 @@
 #
 # Tests for XlsxWriter.
 #
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# SPDX-License-Identifier: BSD-2-Clause
+# Copyright (c), 2013-2024, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -16,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('image_anchor06.xlsx')
+        self.set_filename("image_anchor06.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with image(s)."""
@@ -27,8 +27,10 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         worksheet = workbook.add_worksheet()
 
         worksheet.insert_image(
-            'D7', self.image_dir + 'yellow.png',
-            {'x_offset': 1, 'y_offset': 2, 'positioning': 1})
+            "D7",
+            self.image_dir + "yellow.png",
+            {"x_offset": 1, "y_offset": 2, "positioning": 1},
+        )
 
         workbook.close()
 
