@@ -2,7 +2,8 @@
 #
 # Tests for XlsxWriter.
 #
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# SPDX-License-Identifier: BSD-2-Clause
+# Copyright (c), 2013-2024, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -16,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('rich_string06.xlsx')
+        self.set_filename("rich_string06.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file."""
@@ -26,11 +26,11 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        red = workbook.add_format({'color': 'red'})
+        red = workbook.add_format({"color": "red"})
 
-        worksheet.write('A1', 'Foo', red)
-        worksheet.write('A2', 'Bar')
-        worksheet.write_rich_string('A3', 'ab', red, 'cde', 'fg')
+        worksheet.write("A1", "Foo", red)
+        worksheet.write("A2", "Bar")
+        worksheet.write_rich_string("A3", "ab", red, "cde", "fg")
 
         workbook.close()
 
