@@ -2,7 +2,8 @@
 #
 # Tests for XlsxWriter.
 #
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# SPDX-License-Identifier: BSD-2-Clause
+# Copyright (c), 2013-2024, John McNamara, jmcnamara@cpan.org
 #
 
 from ..excel_comparison_test import ExcelComparisonTest
@@ -16,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('textbox39.xlsx')
+        self.set_filename("textbox39.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with textbox(s)."""
@@ -26,11 +26,13 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        worksheet.insert_textbox('E9', 'This is some text',
-                                 {'url': 'https://github.com/jmcnamara'})
+        worksheet.insert_textbox(
+            "E9", "This is some text", {"url": "https://github.com/jmcnamara"}
+        )
 
-        worksheet.insert_textbox('E19', 'This is some text',
-                                 {'url': 'https://github.com/jmcnamara'})
+        worksheet.insert_textbox(
+            "E19", "This is some text", {"url": "https://github.com/jmcnamara"}
+        )
 
         workbook.close()
 
