@@ -1,11 +1,10 @@
 ###############################################################################
-# _*_ coding: utf-8
 #
 # Tests for XlsxWriter.
 #
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# SPDX-License-Identifier: BSD-2-Clause
+# Copyright (c), 2013-2024, John McNamara, jmcnamara@cpan.org
 #
-from __future__ import unicode_literals
 from ..excel_comparison_test import ExcelComparisonTest
 from ...workbook import Workbook
 
@@ -17,10 +16,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('utf8_05.xlsx')
-
-        self.ignore_files = ['xl/calcChain.xml', '[Content_Types].xml', 'xl/_rels/workbook.xml.rels']
+        self.set_filename("utf8_09.xlsx")
 
     def test_create_file(self):
         """Test the creation of an XlsxWriter file with utf-8 strings."""
@@ -28,8 +24,9 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         workbook = Workbook(self.got_filename)
 
         worksheet = workbook.add_worksheet()
+        num_format = workbook.add_format({"num_format": "[$¥-411]#,##0.00"})
 
-        worksheet.write_formula('A1', '="Café"', None, 'Café')
+        worksheet.write("A1", 1, num_format)
 
         workbook.close()
 
