@@ -2,11 +2,12 @@
 #
 # Tests for XlsxWriter.
 #
-# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
+# SPDX-License-Identifier: BSD-2-Clause
+# Copyright (c), 2013-2024, John McNamara, jmcnamara@cpan.org
 #
 
 import unittest
-from ...compatibility import StringIO
+from io import StringIO
 from ...styles import Styles
 
 
